# coding: utf-8

"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from inductiva.client import schemas  # noqa: F401


class Cost(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "start_ts",
            "cost",
            "end_ts",
            "user",
        }
        
        class properties:
            start_ts = schemas.DateTimeSchema
            end_ts = schemas.DateTimeSchema
            cost = schemas.NumberSchema
            user = schemas.StrSchema
            __annotations__ = {
                "start_ts": start_ts,
                "end_ts": end_ts,
                "cost": cost,
                "user": user,
            }
    
    start_ts: MetaOapg.properties.start_ts
    cost: MetaOapg.properties.cost
    end_ts: MetaOapg.properties.end_ts
    user: MetaOapg.properties.user
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["start_ts"]) -> MetaOapg.properties.start_ts: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["end_ts"]) -> MetaOapg.properties.end_ts: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cost"]) -> MetaOapg.properties.cost: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user"]) -> MetaOapg.properties.user: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["start_ts", "end_ts", "cost", "user", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["start_ts"]) -> MetaOapg.properties.start_ts: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["end_ts"]) -> MetaOapg.properties.end_ts: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cost"]) -> MetaOapg.properties.cost: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user"]) -> MetaOapg.properties.user: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["start_ts", "end_ts", "cost", "user", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        start_ts: typing.Union[MetaOapg.properties.start_ts, str, datetime, ],
        cost: typing.Union[MetaOapg.properties.cost, decimal.Decimal, int, float, ],
        end_ts: typing.Union[MetaOapg.properties.end_ts, str, datetime, ],
        user: typing.Union[MetaOapg.properties.user, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Cost':
        return super().__new__(
            cls,
            *_args,
            start_ts=start_ts,
            cost=cost,
            end_ts=end_ts,
            user=user,
            _configuration=_configuration,
            **kwargs,
        )
